package com.tanpu.community.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.tanpu.community.dao.entity.community.ThemeEntity;
import com.tanpu.community.dao.mapper.community.ThemeMapper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

@Service
public class ThemeService {

    @Resource
    private ThemeMapper themeMapper;

    public void insertTheme(ThemeEntity themeEntity){
        themeMapper.insert(themeEntity);
    }

    //根据id返回主题详情
    public ThemeEntity selectById(String themeId){
        return themeMapper.selectById(themeId);
    }

    //根据话题查询主题
    public List<ThemeEntity> selectByTopic(String topidId){
        return themeMapper.selectList(new LambdaQueryWrapper<ThemeEntity>()
                .eq(ThemeEntity::getTopicId,topidId));
    }
    //查询列表中用户的主题
    public List<ThemeEntity> selectByFans(List<String> fansList) {
        return themeMapper.selectList(new LambdaQueryWrapper<ThemeEntity>()
                .in(ThemeEntity::getAuthorId,fansList)
                .orderByDesc(ThemeEntity::getUpdateTime));

    }

    //查询列表中用户的主题
    public List<ThemeEntity> selectAll() {
        return themeMapper.selectList(new LambdaQueryWrapper<ThemeEntity>()
                .orderByDesc(ThemeEntity::getUpdateTime));
    }

    //查询对应话题的发表用户集合
    public Set<String> getPostUserAmount(List<String> themeIds) {
        return themeMapper.selectBatchIds(themeIds).stream()
                .map(ThemeEntity::getAuthorId)
                .collect(Collectors.toSet());
    }
}
